API
----

.. currentmodule:: djlimiter

Core
====
.. autoclass:: Limiter
.. autofunction:: limit
.. autofunction:: exempt
.. autofunction:: shared_limit


Exceptions
==========
.. autoexception:: RateLimitExceeded

